#!/bin/bash

#OPENSSL=/opt/bin/openssl
OPENSSL=/usr/bin/openssl
CAFILE=/etc/pki/tls/certs/CApublic.crt
VERBOSE=0

LOGFILE="$1"

if [ ${LOGFILE} == "-v" ]; then
	VERBOSE=1
	shift
	LOGFILE="$1"
fi

if [ "z$LOGFILE" == "z" ]; then
	cat <<EOF
Usage: bta-check-timestamp.sh [-v] FILE
	Optionally print the timestamp signature for a file in a textual format,
	and then verify it.

Arguments:
	-v	Print the signature in a textual format

Example:
	You have test.bz2 and test.bz2.tsr, and want to verify the timestamp:
		bta-check-timestamp.sh test.bz2

EOF
	exit 1
fi

if [ $VERBOSE -eq 1 ]; then
	# Print it
	${OPENSSL} ts -reply -in ${LOGFILE}.tsr -text
fi

# Check the timestamp
echo -n "${LOGFILE}: "
${OPENSSL} ts -verify -data ${LOGFILE} -in ${LOGFILE}.tsr -CAfile ${CAFILE}

if [ $? != 0 ]; then
	echo "The signature in the timestamp does not match!"
	exit 77
fi
